@@ -8,7 +8,6 @@ import urllib3; urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarni
 import pandas as pd
 from polity import static
 from polity.static import (
-    CREATE_NEW_USER_MUTATION,
     DATASET_NAME_DESC_QUERY,
     COMPANY_CIK_NAME_QUERY,
     COMPANY_CIK_TICKER_QUERY,
@@ -39,6 +38,7 @@ class Client():
             self.api_key = EQUITIES_PUBLIC_API_KEY
         try:
             self.graphql = self._connect_graphql()
+            #self._login()
             self.dataset_to_desc = self._fetch_dataset_to_desc_map()
             self.cik_to_name = self._fetch_cik_to_name_map()
             self.cik_to_ticker = self._fetch_cik_to_ticker_map()
@@ -64,16 +64,23 @@ class Client():
             transport=transport,
             fetch_schema_from_transport=True,
         )
-        # new user 
+        return graphql
 
+    def _login(self):
         hostname = socket.gethostname()
         ip_addr  = socket.gethostbyname(hostname)
         current_time = str(dt.datetime.now())
 
-        graphql.execute(
-            CREATE_NEW_USER_MUTATION(hostname,ip_addr,current_time)
+        arguments = {
+            "email": ip_addr,
+            "name" : hostname,
+            "photoUrl" : current_time
+        }
+
+        self.graphql.execute(
+            CREATE_NEW_USER_MUTATION
         )
-        return graphql
+
 
     def _test(self):
         for cik in self.ciks()[560:565]:
